﻿using Eneter.Messaging.EndPoints.Rpc;
using Eneter.Messaging.MessagingSystems.MessagingSystemBase;
using Eneter.Messaging.MessagingSystems.TcpMessagingSystem;
using Microsoft.Phone.Controls;
using System.Windows;

namespace CalculatorClientWindowsPhoneSilverlight
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Service interface.
        public interface ICalculator
        {
            int Calculate(int a, int b);
        }

        private IRpcClient<ICalculator> myRpcClient;

        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();
        }

        private void OnConnectBtnClick(object sender, RoutedEventArgs e)
        {
            OpenConnection();
        }

        private void OnDisconnectBtnClick(object sender, RoutedEventArgs e)
        {
            CloseConnection();
        }

        private void OpenConnection()
        {
            // Create RPC client.
            IRpcFactory anRpcFactory = new RpcFactory();
            myRpcClient = anRpcFactory.CreateClient<ICalculator>();

            // Use TCP messaging.
            // Note: provide IP address of your service computer.
            IMessagingSystemFactory aMessaging = new TcpMessagingSystemFactory();
            IDuplexOutputChannel anOutputChannel = aMessaging.CreateDuplexOutputChannel("tcp://192.168.178.31:8099/");

            // Attach output channel and be able to call remote methods.
            myRpcClient.AttachDuplexOutputChannel(anOutputChannel);
        }

        private void CloseConnection()
        {
            myRpcClient.DetachDuplexOutputChannel();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            int a = int.Parse(Number1TextBox.Text);
            int b = int.Parse(Number2TextBox.Text);

            // Call remote method in the service.
            int aResult = (int) myRpcClient.CallRemoteMethod("Calculate", a, b);

            // Display the result.
            ResultTextBox.Text = aResult.ToString();
        }
    }
}