﻿using Eneter.Messaging.EndPoints.Rpc;
using Eneter.Messaging.MessagingSystems.MessagingSystemBase;
using Eneter.Messaging.MessagingSystems.TcpMessagingSystem;
using System;

namespace CalculatorService
{
    // Service interface.
    public interface ICalculator
    {
        int Calculate(int a, int b);
    }

    // SErvice implementation.
    public class Calculator : ICalculator
    {
        public int Calculate(int a, int b)
        {
            return a + b;
        }
    }

    class Program
    {
        static void Main(string[] args)
        {
            //EneterTrace.DetailLevel = EneterTrace.EDetailLevel.Debug;
            //EneterTrace.TraceLog = new StreamWriter("d:/tracefile.txt");

            // Instantiate class which implements the application logic of the service.
            ICalculator aCalculator = new Calculator();

            // Create RPC service.
            IRpcFactory anRpcFactory = new RpcFactory();
            IRpcService<ICalculator> anRpcService = anRpcFactory.CreateSingleInstanceService<ICalculator>(aCalculator);

            // Use TCP for the communication.
            // Note: provide IP address of your service computer.
            IMessagingSystemFactory aMessaging = new TcpMessagingSystemFactory();
            IDuplexInputChannel anInputChannel = aMessaging.CreateDuplexInputChannel("tcp://192.168.178.31:8099/");

            // Attach input channel to the service and start listening.
            anRpcService.AttachDuplexInputChannel(anInputChannel);

            Console.WriteLine("The calculator service is running. Press ENTER to stop.");
            Console.ReadLine();

            // Detach the input channel to stop listening.
            anRpcService.DetachDuplexInputChannel();
        }
    }
}
